function lL=lrLikN(b0,y,x)
// lL=lrLikN(b,y,x)   log-likelihood of logistic regression
//                     with multivariate y (y must start by 0)
//                     Serves as verification of liglikMLR
y=y-min(y);
b=matrix(b0,size(x,2)+1,max(y));

[n m]=size(x);
K=max(y);
x1=[ones(n,1) x];
ny=zeros(1,K+1);
logL=0;
                     
for i=1:n
  z=x1(i,:)*b;
  ez=exp(z);
  sz=1+sum(ez,2);
  p=ez./sz;
  p0=1/(1+sum(ez,2));
  j=y(i);
  if j==0
    logL=logL+log(p0);
  else 
    logL=logL+log(p(j));
  end
end
lL=-logL;
endfunction



function [py, yp, yr, b]=lrEst(b0,y,x)
  //   prediction for LR with multinomial Y
  //
  // yp   prediction 
  // yr   prediction in values 0,1 (rounded yp)
  // b    estimates of parameter (if performed)
  // b0    regression coefficients (b0=[] - with estimation)
  // y    regressand - independent
  // x    regressor - dependaent
  //   
  ymi=min(y);
  y=y-ymi;
  if isempty(b0)
    rand('normal')
    opt=optimset("MaxFunEvals",1e8, "MaxIter",1e8);
    //  opt.Display='off'; 
    //  opt.MaxFunEvals=1e6;
    //  opt.MaxIter=1e3;
    b0=.1*rand(size(x,2)+1,max(y));
    b0=b0(:);
    //fc=list(lrLikN,y,x);                //  
    [b1,v0,ex,op]=fminsearch(list(lrLikN,y,x),b0,opt);
    b=matrix(b1,size(x,2)+1,max(y));
    if ex<1, mprintf('\n Wrong exit condition: ex = %i\n',ex), end
  else
    b=matrix(b0,size(x,2)+1,length(b0)/size(x,2));
  end

  [n m]=size(x);
  nb=size(b,2);
  xp=[ones(n,1) x];
  ex=exp(xp*b);
  se=sum(ex,2);
  dn=(se+1)*ones(1,nb);
  //pause
  py=ex./dn;
  py=[1-sum(py,2) py];
  yr=zeros(n,1);
  for i=1:n
    [mx ix]=max(py(i,:));
    yr(i)=ix-1+ymi;
  end
  yp=py*[ymi:(ymi+nb)]';
endfunction
